# Features in Fedora/Free Electronic Lab

# Known Bugs fixed:
# S#2759043 Segfault in TableModel::handleAspectRemoved() - can't reproduce

Name:              LabPlot
Version:           1.6.0.3
Release:           11%{?dist}
Summary:           Data Analysis and Visualization

License:           GPLv2+
Group:             Applications/Engineering
URL:               http://labplot.sourceforge.net/

BuildRoot:         %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Source0:           http://downloads.sourceforge.net/labplot/%{name}-%{version}.tar.gz

Patch0:            LabPlot-20080225.patch
Patch1:            LabPlot-1.6.0.2-define-missing-constant.patch

BuildRequires:     kdelibs3-devel libselinux-devel desktop-file-utils libexif-devel netcdf-devel
BuildRequires:     gsl-devel ImageMagick-c++-devel fftw-devel jasper-devel qwtplot3d-devel
BuildRequires:     pstoedit libtool qt-qsa-devel gettext htmldoc audiofile-devel ocaml
BuildRequires:     liborigin-devel qhull-devel chrpath
BuildRequires:     R-devel

ExcludeArch:       sparc64 s390 s390x

Requires:          electronics-menu

%description
LabPlot is for scientific 2D and 3D data and function plotting.
The various display and analysis functions are explained in the
handbook (KDE help center). LabPlot also provides a component
for easily viewing the project files in Konqueror.



%package doc
Summary:           Documentation for LabPlot, a Data Analysis and Visualization software
Group:             Documentation
Requires:          %{name} = %{version}-%{release}


%description doc
This package contains the documentation of LabPlot, a Data Analysis and
Visualization software and examples.


%package doc-br
Summary:           Documentation for LabPlot in Brasilian
Group:             Documentation
Requires:          %{name}-doc = %{version}-%{release}

%description doc-br
This package contains the brasilian documentation of LabPlot,
a Data Analysis and Visualization software in the PDF format.


%package doc-de
Summary:           Documentation for LabPlot in German
Group:             Documentation
Requires:          %{name}-doc = %{version}-%{release}

%description doc-de
This package contains the german documentation of LabPlot,
a Data Analysis and Visualization software in the PDF format.


%package doc-fr
Summary:           Documentation for LabPlot in French
Group:             Documentation
Requires:          %{name}-doc = %{version}-%{release}

%description doc-fr
This package contains the german documentation of LabPlot,
a Data Analysis and Visualization software in the PDF format.


%package doc-it
Summary:           Documentation for LabPlot in Italian
Group:             Documentation
Requires:          %{name}-doc = %{version}-%{release}

%description doc-it
This package contains the Italian documentation of LabPlot,
a Data Analysis and Visualization software in the PDF format.


%package doc-nl
Summary:           Documentation for LabPlot in Dutch
Group:             Documentation
Requires:          %{name}-doc = %{version}-%{release}

%description doc-nl
This package contains the Dutch documentation of LabPlot,
a Data Analysis and Visualization software in the PDF format.


%package doc-pl
Summary:           Documentation for LabPlot in Polish
Group:             Documentation
Requires:          %{name}-doc = %{version}-%{release}

%description doc-pl
This package contains the Polish documentation of LabPlot,
a Data Analysis and Visualization software in the PDF format.

%package doc-sv
Summary:           Documentation for LabPlot in Swedish
Group:             Documentation
Requires:          %{name}-doc = %{version}-%{release}

%description doc-sv
This package contains the Swedish documentation of LabPlot,
a Data Analysis and Visualization software in the PDF format.


%prep
%setup -q -n %{name}-%{version}

%patch0 -p1 -b .orig
%patch1 -p1 -b .define-missing-constant


%{__sed} -i.system-wide -e 's|\.\./liborigin/libLabPlotorigin.la||' src/Makefile.in
%{__sed} -i -e '/^libLabPlot_la_LDFLAGS/s|^\(.*\) \\$|\1 -lorigin \\|' src/Makefile.in
%{__sed} -i -e 's|-I../liborigin|-I%{_includedir}/liborigin|' src/Makefile.in
%{__sed} -i.symbol -e '/^LIBS =/s|^\(.*\)|\1 -lm|' cephes/Makefile.in

%{__sed} -i.subdir -e '/^SUBDIR/s|liborigin||' Makefile.in
%{__sed} -i "s|Terminal=yes|Terminal=false|" src/%{name}.desktop

set +x
for f in `find . -name \*.map -or -name \*.MAP | sort` ; do
   echo -n -e "... Fixing the end-of-line encodings of $f  \t"
   sed -i.bak -e 's|\r||g' $f
   touch -r $f.bak $f
   %{__rm} -f $f.bak
   echo "done"
done
set -x

%build
# for netcdf,R and RH#715933
export CPPFLAGS="$CPPFLAGS -DH5_USE_16_API -fno-strict-aliasing -I%{_includedir} -I%{_includedir}/R"
export LDFLAGS="$LDFLAGS -L%{_libdir} -L%{_libdir}/R"

# for qwtplot3d
export QWT3D_PATH="$QTDIR"

# Use of --enable-final: The gsl version 1.7 has a bug which may cause problems.
%configure             \
  --enable-R           \
  --disable-final      \
  --disable-static     \
  --disable-texvc      \
  --enable-gsl         \
  --enable-tiff        \
  --enable-fftw3       \
  --enable-jasper      \
  --enable-ImageMagick \
  --enable-netcdf      \
  --enable-qhull       \
  --enable-system-netcdf \
  --enable-audiofile     \
  --enable-gl            \
  --enable-system-qwtplot3d \
  --enable-libundo          \
  --enable-system-liborigin \
  --disable-rpath \
  --with-qt-librairies=%{_libdir}/qt3

# clean unused-direct-shlib-dependencies
sed -i -e 's! -shared ! -Wl,--as-needed\0!g' libtool


%{__make}


%install
%{__rm} -rf %{buildroot}
%{__make} DESTDIR=%{buildroot} install

# LabPlot is considered to be part of Fedora Electronic LAb
# Compared to qtiplot, LabPlot provides support to various Oscilloscopes.
desktop-file-install \
%if 0%{?fedora} && 0%{?fedora} < 19
    --vendor fedora           \
%endif
    --delete-original                          \
    --remove-category Education                \
    --remove-category Science                  \
    --remove-category Physics                  \
    --remove-category Math                     \
    --add-category "Electronics"               \
    --dir %{buildroot}%{_datadir}/applications \
    %{buildroot}%{_datadir}/applications/kde/%{name}.desktop


#Building pdf handbook for different languages
pushd doc
for LANG in * ; do
  if [ -d $LANG -a $LANG != small_pics -a $LANG != html -a $LANG != fr -a $LANG != Scripting ]; then
    echo "[Fedora-%{name}] building pdf handbook for %{name}-%{version} (language $LANG) ..."

    %{__mkdir} -p tmp/
    %{__cp} -p $LANG/index.docbook tmp/
    %{__cp} -pRL en/common/ en/small_pics/ tmp/

    pushd tmp/
    meinproc --stylesheet %{_datadir}/apps/ksgmltools2/customization/kde-nochunk.xsl index.docbook
    ../makedoc.sh

    htmldoc -f ../%{name}-%{version}-$LANG.pdf index.html

    popd
    %{__rm} -rf emp/

    echo "Done"
  fi
done
popd

%{__mkdir} -p %{buildroot}%{_datadir}/apps/%{name}/handbook
%{__cp} -p doc/%{name}-%{version}-*.pdf %{buildroot}%{_datadir}/apps/%{name}/handbook


# For the doc package
chmod 644 doc/cephes.doc
%{__rm} -f examples/Makefile*

# make sure the examples are UTF-8...
pushd examples
for nonUTF8 in {axeslabel,rydberg,qwt,fit,analysis}.lpl.gz ; do
    /usr/bin/iconv -f iso8859-1 -t utf-8 $nonUTF8 > $nonUTF8.conv && /bin/mv -f $nonUTF8.conv $nonUTF8
done
popd

## File lists
# locale's
%find_lang %{name} || touch %{name}.lang
# HTML (1.0)
HTML_DIR=$(kde-config --expandvars --install html)
if [ -d %{buildroot}$HTML_DIR ]; then
  for lang_dir in %{buildroot}$HTML_DIR/* ; do
    if [ -d $lang_dir -a $lang_dir != %{buildroot}$HTML_DIR/en ]; then
      lang=$(basename $lang_dir)
      #echo "%lang($lang) $HTML_DIR/$lang/*" >> %{name}.lang
      # replace absolute symlinks with relative ones
      pushd $lang_dir
        for i in *; do
          echo "LANGUAGE $i"
          [ -d $i -a -L $i/small_pics ] && \
                %{__rm} -f $i/small_pics && ln -sf ../../en/%{name}/small_pics $i/small_pics
        done
      popd
    fi
  done
fi

# iconv
for f in BUGS ChangeLog TODO WISHLIST ; do
   iconv -f ISO-8859-1 -t UTF-8 $f > $f.tmp && \
      ( touch -r $f $f.tmp ; %{__mv} -f $f.tmp $f ) || \
      %{__rm} -f $f.tmp
done

# Remove useless symbolic links
%{__rm} -f %{buildroot}%{_docdir}/HTML/*/labplot

%{__rm} -f %{buildroot}%{_libdir}/lib*.la

%{__rm} -f %{buildroot}%{_libdir}/lib%{name}.so
%{__rm} -f %{buildroot}%{_libdir}/lib%{name}cephes.so
%{__rm} -f %{buildroot}%{_libdir}/lib%{name}netCDF.so

# rpath fix:
chrpath -d %{buildroot}%{_libdir}/lib%{name}.so*
chrpath -d %{buildroot}%{_bindir}/%{name}

%clean
%{__rm} -rf %{buildroot}


%post
/sbin/ldconfig
touch --no-create %{_datadir}/icons/hicolor || :
%{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
update-desktop-database &> /dev/null ||:


%postun
/sbin/ldconfig
touch --no-create %{_datadir}/icons/hicolor || :
%{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
update-desktop-database &> /dev/null ||:


%files -f %{name}.lang
%doc COPYING README ChangeLog CHANGES FEATURES CREDITS doc/labplot.png
%doc AUTHORS TODO BUGS WISHLIST BUGFIXES LabPlot.lsm doc/cephes.doc
%exclude %{_datadir}/apps/%{name}/handbook/
%{_mandir}/man1/%{name}.*
%{_mandir}/man1/labplot.*
%{_bindir}/%{name}
%{_bindir}/labplot
%{_bindir}/texvc
%if 0%{?fedora} && 0%{?fedora} < 19
%{_datadir}/applications/fedora-%{name}.desktop
%else
%{_datadir}/applications/%{name}.desktop
%endif
%{_datadir}/apps/%{name}/
%{_datadir}/mimelnk/application/x-l?l.desktop
%{_libdir}/lib%{name}.so.1*
%{_libdir}/lib%{name}cephes.so.1*
# needed on Help -> LabPlot Handbook
%{_docdir}/HTML/en/%{name}/

%files doc
%doc doc/html/
%dir %{_datadir}/apps/%{name}/handbook/
%{_datadir}/apps/%{name}/handbook/%{name}-%{version}-en.pdf



%files doc-fr
%{_docdir}/HTML/fr/%{name}/


%files doc-br
%{_datadir}/apps/%{name}/handbook/%{name}-%{version}-br.pdf
%{_docdir}/HTML/br/%{name}/


%files doc-de
%{_datadir}/apps/%{name}/handbook/%{name}-%{version}-de.pdf
%{_docdir}/HTML/de/%{name}/


%files doc-it
%{_datadir}/apps/%{name}/handbook/%{name}-%{version}-it.pdf
%{_docdir}/HTML/it/%{name}/


%files doc-nl
%{_datadir}/apps/%{name}/handbook/%{name}-%{version}-nl.pdf
%{_docdir}/HTML/nl/%{name}/


%files doc-pl
%{_datadir}/apps/%{name}/handbook/%{name}-%{version}-pl.pdf
%{_docdir}/HTML/pl/%{name}/

%files doc-sv
%{_datadir}/apps/%{name}/handbook/%{name}-%{version}-sv.pdf
%{_docdir}/HTML/sv/%{name}/


%changelog
* Tue Jun 16 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.0.3-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun May 17 2015 Orion Poplawski <orion@cora.nwra.com> - 1.6.0.3-10
- Rebuild for hdf5 1.8.15

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 1.6.0.3-9
- Rebuilt for GCC 5 C++11 ABI change

* Thu Jan 08 2015 Orion Poplawski <orion@cora.nwra.com> - 1.6.0.3-8
- Rebuild for hdf5 1.8.14

* Fri Jun 06 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.0.3-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed Mar  6 2013 Toshio Kuratomi <toshio@fedoraproject.org> - 1.6.0.3-3
- Remove vendor prefix from desktop files in F19+ https://fedorahosted.org/fesco/ticket/1077

* Mon Nov 19 2012 Thibault North <tnorth@fedoraproject.org> - 1.6.0.3-1
- Update to 1.6.0.3

* Sun Dec 4 2011 Chitlesh Goorah <chitlesh [AT] fedoraproject DOT org> - 1.6.0.2-9
- Fixes Bug RH#715933 - FTBFS LabPlot-1.6.0.2-8.fc12

* Wed Oct 28 2009 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.6.0.2-8
- fix FTBFS with current GSL (GSL_CONST_CGSM_GAUSS undefined, patch from Debian)

* Sat Oct 24 2009 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.6.0.2-7
- drop ExcludeArch ppc64, OCaml is available for ppc64 these days

* Tue Sep 22 2009 Dennis Gilmore <dennis@ausil.us> - 1.6.0.2-6
- ExcludeArch s390 s390x and sparc64 no ocaml

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.0.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.0.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sun Nov 16 2008 Chitlesh Goorah <chitlesh [AT] fedoraproject DOT org> - 1.6.0.2-3
- handle libLabPlotnetCDF.so* on F-8 and F-9

* Wed Sep 24 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.6.0.2-2
- handle libLabPlotnetCDF.so*

* Wed Sep 24 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.6.0.2-1
- update to 1.6.0.2
- drop useless gcc43 patch, init-smg-before-open-files patch

* Tue Jun 10 2008 Chitlesh Goorah <chitlesh [AT] fedoraproject DOT org> - 1.6.0.1-1
- New upstream release 1.6.0.1
- Now compatible with liborigin 20080225
- Bugfix: #449653: FTBFS LabPlot-1.5.1.6-6.fc9
- Bugfix: #434019: LabPlot failed massrebuild attempt for GCC 4.3
- Added qhull-devel as BR

* Tue Jun 10 2008 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.5.1.6-7
- fix build against latest liborigin on F10 (backported from 1.6.0)

* Sun Apr 12 2008 Thibault North <tnorth [AT] fedoraproject DOT org> - 1.5.1.6-6
- Fixes for GCC 4.3
- Updated dependencies
- Now requires electronics-menu

* Thu Aug 23 2007 Chitlesh Goorah <chitlesh [AT] fedoraproject DOT org> - 1.5.1.6-4
- complying to freedesktop policies - categories
- queued for mass rebuild for Fedora 8 - BuildID
- dropped duplicates - examples/

* Mon Aug 06 2007  Chitlesh Goorah <chitlesh [AT] fedoraproject DOT org> - 1.5.1.6-3
- Excluding PPC64 since it misses ocaml

* Mon Aug 06 2007  Chitlesh Goorah <chitlesh [AT] fedoraproject DOT org> - 1.5.1.6-2
- Update License tag for new Licensing Guidelines compliance

* Mon Jul 30 2007  Chitlesh Goorah <chitlesh [AT] fedoraproject DOT org> - 1.5.1.6-1
- New upstream release

* Mon Apr 23 2007  Chitlesh Goorah <chitlesh [AT] fedoraproject DOT org> - 1.5.1.5-7
- removed parallel build for ppc

* Mon Apr 23 2007  Chitlesh Goorah <chitlesh [AT] fedoraproject DOT org> - 1.5.1.5-6
- added texvc back in %%files
- removed useless .so

* Thu Apr 12 2007  Chitlesh Goorah <chitlesh [AT] fedoraproject DOT org> - 1.5.1.5-5
- split for doc-fr
- duplicate kmenu entries - removed category Science
- corrected missing index.html file from Help -> LabPlot Handbook
- merge -devel package with the main package

* Thu Apr 12 2007 Mamoru Tasaka <mtasaka [AT] ioa.s.u-tokyo.ac.jp> - 1.5.1.5-4.2
- Use system liborigin library
- Shut up undefined non-weak symbols
- Fix end-of-line encodings of [Mm]ap file
- Change the encoding of a part of documents

* Tue Feb 27 2007 Chitlesh Goorah <chitlesh [AT] fedoraproject DOT org> - 1.5.1.5-4
- Added mediawiki and koffice-devel as BR
- using liborigin system wide
- Dropped mediawiki as BR
- Fixed presence on gnome menu

* Sat Jan 13 2007 Chitlesh Goorah <chitlesh [AT] fedoraproject DOT org> - 1.5.1.5-3
- manual dependencies removed
- dropped additional arguments for x86_64 sparc64 ppc64 amd64

* Wed Jan 03 2007 Chitlesh Goorah <chitlesh [AT] fedoraproject DOT org> - 1.5.1.5-2
- Added audiofile-devel, qwtplot3d-devel, ocaml and netcdf-devel as BR
- using qwtplot3d and netcdf system wide #221022
- Fixed qt-qsa headers

* Sun Dec 31 2006 Chitlesh Goorah <chitlesh [AT] fedoraproject DOT org> - 1.5.1.5-1
- New stable release 1.5.1.5
- Fixed symlink-should-be-relative rpmlint issues
- Removed numerous entries on kmenu
- Added examples in a new -doc package
- Building pdf handbook for different languages
- Breaking down -doc package for different languages

* Sun Nov 19 2006 Chitlesh Goorah <chitlesh [AT] fedoraproject DOT org> - 1.5.1.4-1
- Initial package
